/*
 *    Copyright (c) 2018-2025, hnqz All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the pig4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: hnqz
 */

import request from "@/router/axios";

// 分页查询
export function reportPage(query) {
  return request({
    url: "/admin/wmreport/reportPage",
    method: "get",
    params: query
  });
}

// 查看
export function getTaskListPage(query) {
  return request({
    url: "/admin/wmreport/getTaskListPage",
    method: "get",
    params: query
  });
}

// 审批
export function approvalReport(query) {
  return request({
    url: "/admin/wmreport/approvalReport",
    method: "get",
    params: query
  });
}

// 结单
export function updateReportStatus(obj) {
  return request({
    url: "/admin/wmreport/updateReportStatus",
    method: "post",
    data: obj
  });
}

// 退回
export function backStatus(obj) {
  return request({
    url: "/admin/wmreport/updateReportStatus",
    method: "post",
    data: obj
  });
}

// 导出报告
export function exportNbReport(query) {
  return request({
    url: "/admin/reportExport/exportNbReport",
    method: "get",
    params: query
  });
}
// 导出报告
export function exportExcelNbReport(query) {
  return request({
    url: "/admin/report/excel/export/exportNbReport",
    method: "get",
    params: query
  });
}

// 根据任务类型查询任务列表(服务审核-我的任务)
export function getTaskPageByType(query) {
  return request({
    url: "/admin/wmreport/task-page-by-type",
    method: "get",
    params: query
  });
}

// 审批/批量审批(仅用于根据任务类型查询的列表)
export function approvalReportByTask(data) {
  return request({
    url: `/admin/wmreport/approval-report-by-task?taskIds=${
      data.taskIds
    }&approvalOpinion=${data.approvalOpinion}&approvalInfo=${
      data.approvalInfo
    }`,
    method: "post"
  });
}

// 复审
export function reviewTask(obj) {
  return request({
    url: "/admin/wmreport/review-task",
    method: "post",
    data: obj
  });
}

// 新的审核
export function nodeHistoryCreateApi(obj) {
  return request({
    url: "/admin/wmtask/task/check/node/history/create",
    method: "post",
    data: obj
  });
}
